<p align="center">
   <img src="https://user-images.githubusercontent.com/32339251/95760847-2265f880-0cc9-11eb-8cd5-ca641cea0771.png" alt="" width="160" />
   <h3 align="center">Reactonite</h3>
   
   <p align="center"><img src="https://github.com/SDOS2020/Team_3_Reactonite/workflows/Python%20Linter/badge.svg?branch=beta" />
   <a onclick="window.open(this.href,'_blank');return false;" href="https://reactonite.github.io/"><img src="https://img.shields.io/website?label=documentation&up_message=up&url=https%3A%2F%2Freactonite.github.io%2F"/></p></a>

   <p align="center">
      A transpiler to convert HTML to React code and PWAs ✨
      </br>
      <a href="https://reactonite.github.io/"><strong>Explore the Docs »</strong></a>
      <br/>
      <a href="https://github.com/SDOS2020/Team_3_Reactonite/#table-of-contents">Table of Contents</a> . <a href="https://github.com/SDOS2020/Team_3_Reactonite/issues">Report Bug</a> . <a href="https://github.com/SDOS2020/Team_3_Reactonite/projects">View Project</a>
   </p>
</p>

<!-- TABLE OF CONTENTS -->

## Table of Contents

- [Table of Contents](#table-of-contents)
- [About The Project](#about-the-project)
  - [Built With](#built-with)
- [Getting Started](#getting-started)
  - [Prerequisites](#prerequisites)
  - [Installation](#installation)
  - [Development Setup](#development-setup)
- [Usage](#usage)
- [Roadmap](#roadmap)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)

<!-- ABOUT THE PROJECT -->

## About The Project

Reactonite is a wrapper for React which allows one to write vanilla html code and convert it to a react code and hence building a PWA, SPA.

Here's the key features added to Reactonite:

- Transpile HTML code to React website
- Create PWAs and React applications as quickly as possible
- Act as a wrapper to NPM
- Allow importing of already created HTML file components
- Hot Reloading
- Support custom scss, js, css etc. :smile:

### Built With

This project was bootstrapped with [Create React App](https://github.com/facebook/create-react-app)

<!-- GETTING STARTED -->

## Getting Started

To get this repo up and running on your local machine follow these simple steps.

### Prerequisites

Here's a list of things you'll need to have prior to installing the software.

- Python
- NPM
- NodeJs
- Any modern web browser

### Installation

1. Use pip to install Reactonite

```sh
$ pip install reactonite
```

### Development Setup

1. Setup virtual environment?

```sh
$ virtualenv venv
```

> Not necessary but recommended to keep your environment clean.
> Dont forget to activate it.

2. Clone the repository to local machine.

```sh
$ git clone https://github.com/SDOS2020/Team_3_Reactonite.git
```

3. Install the package either using pip or python setup tools

```sh
$ python setup.py install
# Use `develop` instead of `install` to get an editable build

# Alternatively run
$ pip install .
```

3. You are good to go... 🎉

<!-- USAGE EXAMPLES -->

## Usage

Once installed refer to the [documentation](https://reactonite.github.io/) for the set of commands available with Reactonite cli or you can begin by typing `reactonite --help` which opens the help page for `reactonite` command line tool.

```sh
$ reactonite --help
Usage: reactonite [OPTIONS] COMMAND [ARGS]...

  Entry point for Reactonite cli.

Options:
  --help  Show this message and exit.

Commands:
  ...
```

<!-- ROADMAP -->

## Roadmap

See the [open issues](https://github.com/SDOS2020/Team_3_Reactonite/issues) for a list of proposed features (and known issues). You can also track where the project is going in further releases just visit the [projects](https://github.com/SDOS2020/Team_3_Reactonite/projects) tab.

<!-- CONTRIBUTING -->

## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**. For complete contributing guide please read our [code of conduct](https://github.com/SDOS2020/Team_3_Reactonite/blob/beta/CONTRIBUTING.md).

<!-- LICENSE -->

## License

MIT License. See `LICENSE` for more information once complete.

<!-- CONTACT -->

## Contact

- Amogh Gulati - amogh17019@iiitd.ac.in
- Aniket Pradhan - aniket17133@iiitd.ac.in
- Avi Garg - avi17223@iiitd.ac.in
- Chirag Jain - chirag17041@iiitd.ac.in

Project Link: [https://github.com/SDOS2020/Team_3_Reactonite](https://github.com/SDOS2020/Team_3_Reactonite)
